@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 
-from understanding_imports import directory_finder
+from UnderstandingImportsForTesting import directory_finder
 
 
 def main():
